@@ -214,7 +214,7 @@ typedef int GPid;
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
-#undef G_HAVE_FREE_SIZED
+#define G_HAVE_FREE_SIZED
 
 G_END_DECLS
 
